"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
const awsLambdaUtils_1 = require("../../../awsLambdaUtils");
const getProcessTransformEventParams = (qpqConfig) => {
    return ({ eventParams: [cloudFrontRequestEvent, context] }) => __awaiter(void 0, void 0, void 0, function* () {
        const cfRecordRequest = cloudFrontRequestEvent.Records[0].cf.request;
        const headers = Object.keys(cfRecordRequest.headers).reduce((acc, header) => (Object.assign(Object.assign({}, acc), { [header]: cfRecordRequest.headers[header][0].value })), {});
        return (0, quidproquo_core_1.actionResult)({
            domain: quidproquo_webserver_1.qpqWebServerUtils.getBaseDomainName(qpqConfig),
            body: cfRecordRequest.body,
            correlation: context.awsRequestId,
            method: cfRecordRequest.method,
            path: cfRecordRequest.uri,
            sourceIp: cfRecordRequest.clientIp,
            headers: headers,
            // TODO: query string support
            query: {},
        });
    });
};
const getProcessTransformResponseResult = (configs) => {
    return ({ response }) => __awaiter(void 0, void 0, void 0, function* () {
        return (0, quidproquo_core_1.actionResult)(response);
    });
};
const getProcessAutoRespond = () => {
    return (payload) => __awaiter(void 0, void 0, void 0, function* () {
        return (0, quidproquo_core_1.actionResult)(null);
    });
};
const getProcessMatchStory = (seoConfigs) => {
    return (payload) => __awaiter(void 0, void 0, void 0, function* () {
        /// Sort the routes by string length
        // Note: We may need to filter variable routes out {} as the variables are length independent
        const sortedSeoConfigs = seoConfigs.sort((a, b) => {
            if (a.path.length < b.path.length)
                return -1;
            if (a.path.length > b.path.length)
                return 1;
            return 0;
        });
        // Find the most relevant match
        const matchedSeoConfig = sortedSeoConfigs
            .map((r) => ({
            match: (0, awsLambdaUtils_1.matchUrl)(r.path, payload.transformedEventParams.path),
            route: r,
        }))
            .find((m) => m.match.didMatch);
        if (!matchedSeoConfig) {
            return (0, quidproquo_core_1.actionResultError)(quidproquo_core_1.ErrorTypeEnum.NotFound, `seo not found [${payload.transformedEventParams.path}]`);
        }
        return (0, quidproquo_core_1.actionResult)({
            src: matchedSeoConfig.route.src,
            runtime: matchedSeoConfig.route.runtime,
            runtimeOptions: matchedSeoConfig.match.params || {},
            config: matchedSeoConfig.route,
        });
    });
};
exports.default = (config) => {
    const seoConfigs = quidproquo_webserver_1.qpqWebServerUtils.getAllSeo(config);
    return {
        [quidproquo_core_1.EventActionType.TransformEventParams]: getProcessTransformEventParams(config),
        [quidproquo_core_1.EventActionType.TransformResponseResult]: getProcessTransformResponseResult(config),
        [quidproquo_core_1.EventActionType.AutoRespond]: getProcessAutoRespond(),
        [quidproquo_core_1.EventActionType.MatchStory]: getProcessMatchStory(seoConfigs),
    };
};
