"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
// TODO: Don't use Globals like this
const GLOBAL_WEBSOCKET_API_NAME = process.env.websocketApiName;
const awsToQoqEventTypeMap = {
    "MESSAGE": quidproquo_webserver_1.WebSocketEventType.Message,
    "CONNECT": quidproquo_webserver_1.WebSocketEventType.Connect,
    "DISCONNECT": quidproquo_webserver_1.WebSocketEventType.Disconnect,
};
const getProcessTransformEventParams = () => {
    return ({ eventParams: [websocketEvent, context] }) => __awaiter(void 0, void 0, void 0, function* () {
        const transformedEventParams = {
            eventType: awsToQoqEventTypeMap[websocketEvent.requestContext.eventType],
            messageId: websocketEvent.requestContext.messageId,
            connectionId: websocketEvent.requestContext.connectionId,
            requestTimeEpoch: websocketEvent.requestContext.requestTimeEpoch,
            sourceIp: websocketEvent.requestContext.identity.sourceIp,
            userAgent: websocketEvent.requestContext.identity.userAgent,
            requestTime: new Date(websocketEvent.requestContext.requestTimeEpoch).toISOString(),
            body: websocketEvent.body
        };
        return (0, quidproquo_core_1.actionResult)(transformedEventParams);
    });
};
const getProcessTransformResponseResult = (qpqConfig) => {
    // We might need to JSON.stringify the body.
    return (payload) => __awaiter(void 0, void 0, void 0, function* () {
        // always success
        return (0, quidproquo_core_1.actionResult)({
            statusCode: 200,
        });
    });
};
const getProcessAutoRespond = (qpqConfig) => {
    return (payload) => __awaiter(void 0, void 0, void 0, function* () {
        // always allow
        return (0, quidproquo_core_1.actionResult)(false);
    });
};
const getProcessMatchStory = (qpqConfig) => {
    const userDirectoryConfig = quidproquo_webserver_1.qpqWebServerUtils.getWebsocketEntryByApiName(GLOBAL_WEBSOCKET_API_NAME, qpqConfig);
    return (payload) => __awaiter(void 0, void 0, void 0, function* () {
        switch (payload.transformedEventParams.eventType) {
            case quidproquo_webserver_1.WebSocketEventType.Connect:
                return (0, quidproquo_core_1.actionResult)({
                    src: userDirectoryConfig.eventProcessors.onConnect.src,
                    runtime: userDirectoryConfig.eventProcessors.onConnect.runtime
                });
            case quidproquo_webserver_1.WebSocketEventType.Disconnect:
                return (0, quidproquo_core_1.actionResult)({
                    src: userDirectoryConfig.eventProcessors.onDisconnect.src,
                    runtime: userDirectoryConfig.eventProcessors.onDisconnect.runtime
                });
            case quidproquo_webserver_1.WebSocketEventType.Message:
                return (0, quidproquo_core_1.actionResult)({
                    src: userDirectoryConfig.eventProcessors.onMessage.src,
                    runtime: userDirectoryConfig.eventProcessors.onMessage.runtime
                });
            default:
                return (0, quidproquo_core_1.actionResultError)(quidproquo_core_1.ErrorTypeEnum.NotFound, `Websocket lambda not implemented for ${payload.transformedEventParams.eventType}`);
        }
    });
};
exports.default = (qpqConfig) => {
    return {
        [quidproquo_core_1.EventActionType.TransformEventParams]: getProcessTransformEventParams(),
        [quidproquo_core_1.EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
        [quidproquo_core_1.EventActionType.AutoRespond]: getProcessAutoRespond(qpqConfig),
        [quidproquo_core_1.EventActionType.MatchStory]: getProcessMatchStory(qpqConfig),
    };
};
