"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.memoFunc = void 0;
const node_cache_1 = __importDefault(require("node-cache"));
const cache = new WeakMap();
/**
 * Memoizes a function by caching its return values.
 * @param func The function to memoize.
 * @param ttlInSeconds Time-to-live for the cached values in seconds.
 * @returns The memoized function.
 */
const memoFunc = (func, ttlInSeconds = 3600) => {
    return ((...args) => {
        // Check if the function has a corresponding cache entry
        if (!cache.has(func)) {
            // Create a new NodeCache instance and store it in the cache
            cache.set(func, new node_cache_1.default({ stdTTL: ttlInSeconds }));
        }
        const cacheKey = JSON.stringify(args);
        const nodeCache = cache.get(func);
        const cachedValue = nodeCache.get(cacheKey);
        if (cachedValue) {
            return cachedValue;
        }
        // Call the original function if the value is not cached
        const result = func(...args);
        // Cache the result for future use
        nodeCache.set(cacheKey, result);
        return result;
    });
};
exports.memoFunc = memoFunc;
