"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.listPagedUsers = void 0;
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const cognitoAttributeMap_1 = require("./cognitoAttributeMap");
const utils_1 = require("./utils");
const listPagedUsers = (userPoolId, region, pageKey) => __awaiter(void 0, void 0, void 0, function* () {
    const cognitoClient = new client_cognito_identity_provider_1.CognitoIdentityProviderClient({ region });
    const response = yield cognitoClient.send(new client_cognito_identity_provider_1.ListUsersCommand({
        UserPoolId: userPoolId,
        PaginationToken: (0, utils_1.pageKeyToPaginationToken)(pageKey),
    }));
    const users = (response.Users || []).map((user) => {
        const validAttributes = (user.Attributes || []).filter((attr) => attr.Name && attr.Value);
        return (0, cognitoAttributeMap_1.getQpqAttributesFromCognitoUserAttributes)(validAttributes);
    });
    return {
        nextPageKey: (0, utils_1.paginationTokenToPageKey)(response.PaginationToken),
        items: users,
    };
});
exports.listPagedUsers = listPagedUsers;
