"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLogByCorrelation = void 0;
const client_dynamodb_1 = require("@aws-sdk/client-dynamodb");
function getLogByCorrelation(tableName, region, correlation) {
    return __awaiter(this, void 0, void 0, function* () {
        const dynamoDBClient = new client_dynamodb_1.DynamoDBClient({ region });
        const queryParams = {
            TableName: tableName,
            IndexName: 'CorrelationIndex',
            KeyConditionExpression: 'correlation = :correlation',
            ExpressionAttributeValues: {
                ':correlation': { S: correlation },
            },
        };
        try {
            const queryResult = yield dynamoDBClient.send(new client_dynamodb_1.QueryCommand(queryParams));
            const items = (queryResult.Items || []).map((i) => {
                var _a, _b, _c;
                const [startedAt, correlation] = ((_a = i.startedAtWithCorrelation.S) === null || _a === void 0 ? void 0 : _a.split('#')) || [];
                const metaData = {
                    generic: i.generic.S || '',
                    runtimeType: i.runtimeType.S,
                    error: (_b = i.error) === null || _b === void 0 ? void 0 : _b.S,
                    startedAt: startedAt,
                    correlation,
                    moduleName: i.moduleName.S || '',
                    fromCorrelation: (_c = i.fromCorrelation) === null || _c === void 0 ? void 0 : _c.S,
                };
                return metaData;
            });
            const [result] = items;
            if (!result) {
                throw new Error(`Failed to find log with correlation: ${correlation}`);
            }
            return result;
        }
        catch (err) {
            console.error(`Failed to find log: ${err}`);
            throw err;
        }
    });
}
exports.getLogByCorrelation = getLogByCorrelation;
